import os
import launch
from pathlib import Path
from launch_ros.actions import Node
from tracetools_launch.action import Trace

def generate_launch_description():
    length_arg = launch.actions.DeclareLaunchArgument(
        'length',
        default_value='60.0',
        description='length of execution in seconds',
    )

    file_dir = Path(__file__).resolve().parent
    target_path = file_dir.parents[2] / 'analysis' / 'tracing'

    return launch.LaunchDescription([
        length_arg,
        Trace(
            session_name='trace_full_topology',
            append_timestamp=True,
            base_path=target_path,
            events_ust=[
                'dds:*',
                'ros2:*',
                'rcl:*',
                'rmw:*',
                'rclcpp:*',
                'rclcpp:*callback*',
                'rclcpp:*executor*',
                'rmw_cyclonedds:*',
            ],
            events_kernel=[],
        ),
        Node(
            package='full_topology',
            executable='full_topology',
            output='screen',
        ),
        # Shut down after some time, otherwise the system would run indefinitely
        launch.actions.TimerAction(
            period=launch.substitutions.LaunchConfiguration(length_arg.name),
            actions=[launch.actions.Shutdown(reason='stopping system')],
        ),
    ])
